@@ -2,8 +2,8 @@ import base64
 import hmac
 from urllib.parse import quote
 
-from requests.auth import AuthBase
 from requests import PreparedRequest
+from requests.auth import AuthBase
 
 from .config import AuthConfig
 from .utils import http_date
@@ -18,8 +18,8 @@ class XCoverAuth(AuthBase):
         api_secret = self.config.api_secret
         headers = self.config.headers
         algorithm = self.config.algorithm.value
-        date = http_date()
-        request.headers["date"] = date
+        if not request.headers.get("date"):
+            request.headers["date"] = http_date()
 
         signature = hmac.new(
             key=api_secret.encode("utf-8", "strict"),
@@ -28,7 +28,10 @@ class XCoverAuth(AuthBase):
         ).digest()
 
         signature = quote(base64.b64encode(signature), safe="")
-        auth_header = f'Signature keyId="{api_key}",algorithm="{algorithm}",headers="{headers}",signature="{signature}"'
+        auth_header = (
+            f'Signature keyId="{api_key}",algorithm="{algorithm}",'
+            f'headers="{headers}",signature="{signature}"'
+        )
 
         request.headers["authorization"] = auth_header
 
